import sqlite3


class Database:

    database_dir: str

    connection: sqlite3.Connection

    create_song_links_table = """
    CREATE TABLE IF NOT EXISTS song_links (
        id              INTEGER       PRIMARY KEY   AUTOINCREMENT, 
        link            VARCHAR(255)                NOT NULL
    ); 
    """

    create_song_info_table = """
    CREATE TABLE IF NOT EXISTS song_info (
        id              INTEGER       PRIMARY KEY   AUTOINCREMENT,
        title           VARCHAR(255)                NOT NULL,
        song_link_id    INTEGER,
        
        FOREIGN KEY(song_link_id) REFERENCES song_links(id)
    );
    """

    tables: list = [create_song_links_table, create_song_info_table]

    def __init__(self, database_dir: str):
        self.database_dir = database_dir

    def connect(self) -> bool:
        try:
            self.connection = sqlite3.Connection(self.database_dir)
        except sqlite3.Error as e:
            # TODO should be logged
            print(e)

            return False

        return True

    def disconnect(self):
        self.connection.close()

    def create_tables(self) -> bool:
        cursor = self.connection.cursor()

        for table in self.tables:
            try:
                cursor.execute(table)
            except sqlite3.Error as e:
                # TODO should be logged
                print(e)

                return False

        return True

    def insert_song_link(self, link: str) -> bool:
        if self.connection is not None:
            cursor = self.connection.cursor()

            # search for the url in the database
            cursor.execute("SELECT * FROM song_links WHERE link=?", (link, ))
            rows = cursor.fetchall()

            # if no entry is found insert the video url
            if len(rows) == 0:
                cursor.execute("INSERT INTO song_links (link) VALUES (?);", (link,))
                self.connection.commit()

                return True

            return False

    def insert_song_title(self, link: str, title: str):
        if self.connection is not None:
            cursor = self.connection.cursor()

            # get the song id of the given link
            cursor.execute("SELECT id FROM song_links WHERE link=? LIMIT 1", (link, ))
            song_id = cursor.fetchall()

            cursor.execute("INSERT INTO song_info (title, song_link_id) VALUES (?, ?)", (title, song_id[0][0]))
            self.connection.commit()

    def get_song_title(self, link: str) -> str:
        if self.connection is not None:
            cursor = self.connection.cursor()

            # get the song id of the given link
            cursor.execute("SELECT id FROM song_links WHERE link=? LIMIT 1", (link,))
            song_id = cursor.fetchall()

            cursor.execute("SELECT title FROM song_info WHERE song_link_id=?", (song_id[0][0], ))
            title = cursor.fetchall()

            self.connection.commit()

            return title[0][0]
