""" Provide some helper functions """

import os
import fnmatch


def directory_exist(path) -> bool:
    """Test if a path exists

    Args:
        path (str): The file path

    Returns:
        True if the file path exists. False otherwise

    """

    if os.path.exists(path) and os.path.isdir(path):
        return True
    return False


def create_directory(path) -> bool:
    """Create a directory

    Args:
        path (str): The path of the directory

    Returns:
        True if the directory could be created. False otherwise

    """

    try:
        os.makedirs(path)
    except OSError as e:
        print(e)
        return False
    else:
        return True


def list_directory(path, pattern = "*", file_extension = None) -> list:
    """Get a list of all files in a directory which fulfill a given filer

    Args:
        path (str): The file path to search
        pattern (str): The filter as regex pattern. Defaults to '*'
        file_extension (str): The file extensions to be included. Default to None

    Returns:
        A list of all files which fulfill the pattern and file_extension

    """

    if file_extension is not None:
        return fnmatch.filter(os.listdir(path), "*." + file_extension)

    return fnmatch.filter(os.listdir(path), pattern)


def get_file_path(file) -> str:
    """Get the path of a file

    Args:
        file (str): The file with path

    Returns:
        The path without the filename

    """

    return os.path.split(file)[0] + '/'


def test_config_file(config) -> bool:
    """Test a configuration file

    Arguments:
        config (configparser.ConfigParser): The config object

    Returns:
        True if the config file is not empty. False otherwise

    """
    
    if len(config) < 2:
        return False

    return True
