"""Provide tkinter message boxes

If a message box in tkinter is called it will also display the root window.
The functions provided in this module call the tkinter message boxes but hide
the root window
"""

from functools import wraps

import tkinter as tk
from tkinter import messagebox


def __display_messagebox(message_type):
    """Display the message box and hide the root window"""

    @wraps(message_type)
    def wrapper(title, message):
        root = tk.Tk()
        root.withdraw()

        message_type(title, message)

    return wrapper


@__display_messagebox
def showerror(title, message):
    """Display an error message dialog box

    Arguments:
        title (str): The dialog title
        message (str): The message displayed in the dialog

    """

    messagebox.showerror(title, message)
