from moviepy.editor import *

from typing import Callable


class Mp3Converter:
    """Convert a mp4 file into a mp3 file"""
    maximum: int

    __callback_chunk_size: Callable[[int], None]
    __callback_progress: Callable[[int], None]

    def __init__(self):
        pass

    def convert_to_mp3(self, video_path, video_title):
        """Convert a video file into an audio file

        Args:
            video_path (str): The path of the video
            video_title (str): The title of the video

        """

        self.maximum = 0

        try:
            title = video_title + '.mp4'
            video = VideoFileClip(os.path.join(video_path, title))

            title = video_title + '.mp3'
            video.audio.write_audiofile(os.path.join(video_path, title),
                                        callback_chunk_size=self.__callback_chunk_size,
                                        callback_progress=self.__callback_progress)
        except RuntimeError:
            print("Error converting to audio")

        print("Finished")

    def register_callback_chunk_size(self, callback_chunk_size):
        """Register a callback function for the chunk size

        Args:
            callback_chunk_size (Callable[[int], None]): Callback function

        """

        self.__callback_chunk_size = callback_chunk_size

    def register_callback_progress(self, callback_progress):
        """Register a callback function for the converting progress

        Args:
            callback_progress (Callable[[int], None]): Callback function

        """

        self.__callback_progress = callback_progress
